==> elasticsearch-2024.2.236+6b985e51b.tgz: elasticsearch/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Update to 7.6.2 image
- 0.1.3 Add elasticsearch snapshot policy template for SLM
- 0.1.4 Add elasticsearch ILM functionality
- 0.1.5 Make templates job more generic
- 0.1.6 Fix elasticsearch-master rendering error
- 0.1.7 Pin Java options to specific versions
- 0.1.8 Disable Curator in Gate & Chart Defaults
- 0.2.0 Add more S3 configuration options
- 0.2.1 Make templates job more robust & allow overrides
- 0.2.2 Update the ES curator config to {}
- 0.2.3 Add configurable backoffLimit to templates job
- 0.2.4 Update helm-test script
- 0.2.5 Enable TLS with Kibana
- 0.2.6 Enable TLS path between nodes in cluster and TLS path between ceph-rgw
- 0.2.7 Get connection option from values.yaml
- 0.2.8 Use full image ref for docker official images
- 0.2.9 Removed repo verification check from helm-test
- 0.2.10 Enable TLS path between Prometheus-elasticsearch-exporter and Elasticsearch
- 0.2.11 Enable TLS path between Curator and Elasticsearch
- 0.2.12 Helm 3 - Fix Job labels
- 0.2.13 Update htk requirements
- 0.2.14 Fix cronjob rendering
- 0.2.15 Fix elasticsearch-data shutdown
- 0.2.16 Use python3 for helm tests when possible
- 0.2.17 Annotate ES master/data sts with S3 secret hash
- 0.2.18 Update default image value to Wallaby
- 0.2.19 Migrated CronJob resource to batch/v1 API version
- 0.2.20 Set default python for helm test
- 0.2.21 Added OCI registry authentication
- 0.2.22 Update all Ceph images to Focal
- 0.2.23 Add configurable liveness probe for elasticsearch client
- 0.2.24 Update Ceph to 17.2.6
- 0.2.25 Update ElasticSearch to 8.9.0
- 0.2.26 Add 2023.1 Ubuntu Focal overrides
- 0.2.27 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.2.28 Utilize bucket claim CRD when using with Rook
- 0.2.29 Make es curator path configurable
- 0.2.30 Update curator for es v8
- 0.3.0 Update elasticsearch_exporter to v1.7.0
- 0.3.1 Update Ceph images to Jammy and Reef 18.2.1
- 0.3.2 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.3.3 Update es curator to 8.0.10
- 0.3.4 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.3.5 Remove gateway node role
- 0.3.6 Add 2024.1 Ubuntu Jammy overrides
- 0.3.7 Add 2024.2 overrides
- 0.3.8 Remove use of python in helm tests
- 0.3.9 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> elasticsearch-2025.1.4+35052e51b.tgz: elasticsearch/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

- Upgrade to the latest v8.18.1
- Replace the elasticsearch_templates image with a lighweight upstream image that includes yq and jq
- Switch to the upstream image, as S3 repository support is natively integrated starting from v8.x (https://www.elastic.co/guide/en/elasticsearch/plugins/8.0/repository-s3.html) and elasticsearch_templates is replaced to use jq
- Upgrade the Prometheus elasticsearch-exporter to the latest v1.9.0
- Rename the slm flag according to the changelog https://github.com/prometheus-community/elasticsearch_exporter/releases/tag/v1.9.0

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Update to 7.6.2 image
- 0.1.3 Add elasticsearch snapshot policy template for SLM
- 0.1.4 Add elasticsearch ILM functionality
- 0.1.5 Make templates job more generic
- 0.1.6 Fix elasticsearch-master rendering error
- 0.1.7 Pin Java options to specific versions
- 0.1.8 Disable Curator in Gate & Chart Defaults
- 0.2.0 Add more S3 configuration options
- 0.2.1 Make templates job more robust & allow overrides
- 0.2.2 Update the ES curator config to {}
- 0.2.3 Add configurable backoffLimit to templates job
- 0.2.4 Update helm-test script
- 0.2.5 Enable TLS with Kibana
- 0.2.6 Enable TLS path between nodes in cluster and TLS path between ceph-rgw
- 0.2.7 Get connection option from values.yaml
- 0.2.8 Use full image ref for docker official images
- 0.2.9 Removed repo verification check from helm-test
- 0.2.10 Enable TLS path between Prometheus-elasticsearch-exporter and Elasticsearch
- 0.2.11 Enable TLS path between Curator and Elasticsearch
- 0.2.12 Helm 3 - Fix Job labels
- 0.2.13 Update htk requirements
- 0.2.14 Fix cronjob rendering
- 0.2.15 Fix elasticsearch-data shutdown
- 0.2.16 Use python3 for helm tests when possible
- 0.2.17 Annotate ES master/data sts with S3 secret hash
- 0.2.18 Update default image value to Wallaby
- 0.2.19 Migrated CronJob resource to batch/v1 API version
- 0.2.20 Set default python for helm test
- 0.2.21 Added OCI registry authentication
- 0.2.22 Update all Ceph images to Focal
- 0.2.23 Add configurable liveness probe for elasticsearch client
- 0.2.24 Update Ceph to 17.2.6
- 0.2.25 Update ElasticSearch to 8.9.0
- 0.2.26 Add 2023.1 Ubuntu Focal overrides
- 0.2.27 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.2.28 Utilize bucket claim CRD when using with Rook
- 0.2.29 Make es curator path configurable
- 0.2.30 Update curator for es v8
- 0.3.0 Update elasticsearch_exporter to v1.7.0
- 0.3.1 Update Ceph images to Jammy and Reef 18.2.1
- 0.3.2 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.3.3 Update es curator to 8.0.10
- 0.3.4 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.3.5 Remove gateway node role
- 0.3.6 Add 2024.1 Ubuntu Jammy overrides
- 0.3.7 Add 2024.2 overrides
- 0.3.8 Remove use of python in helm tests
- 0.3.9 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
